@@ -1,5 +1,5 @@
 import os
-from sklearn.externals import joblib
+import joblib
 from .funcs import disk_2_s3, wget
 
 def dump_clf(clf, s3_path):
